@@ -1,20 +1,9 @@
 /*
- * Copyright 2009 Mathias Kraus <k.hias@gmx.de>
- * Copyright 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2009 Mathias Kraus <k.hias@gmx.de>
+    SPDX-FileCopyrightText: 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "elementitem.h"
 #include "element.h"
@@ -29,7 +18,7 @@ ElementItem::ElementItem(Element* p_model, KGameRenderer* renderer) : KGameRende
     // Init the view coordinates
     update(p_model->getX(), p_model->getY());
     // Connects the model to the view
-    connect(p_model, SIGNAL(moved(qreal,qreal)), this, SLOT(update(qreal,qreal)));
+    connect(p_model, &Element::moved, this, &ElementItem::update);
 
     m_renderSize = QSize(1, 1);
     m_itemSizeSet = QSize(static_cast<int>(Granatier::CellSize), static_cast<int>(Granatier::CellSize));
