@@ -1,21 +1,10 @@
 /*
- * Copyright 2009 Mathias Kraus <k.hias@gmx.de>
- * Copyright 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
- * Copyright 2007-2008 Alexandre Galinier <alex.galinier@hotmail.com>
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License as
- * published by the Free Software Foundation; either version 2 of
- * the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2009 Mathias Kraus <k.hias@gmx.de>
+    SPDX-FileCopyrightText: 2007-2008 Thomas Gallinari <tg8187@yahoo.fr>
+    SPDX-FileCopyrightText: 2007-2008 Alexandre Galinier <alex.galinier@hotmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "gamescene.h"
 #include "cell.h"
@@ -343,7 +332,7 @@ void GameScene::initItemsWithGraphicsFromTheme()
             if (!blockElements.isEmpty())
             {
                 // Create the element item and set the image
-                for(const auto& element: qAsConst(blockElements))
+                for(const auto& element: std::as_const(blockElements))
                 {
                     Block* block = dynamic_cast <Block*> (element);
                     BlockItem* blockItem = new BlockItem(block, m_rendererArenaItems);
@@ -685,7 +674,7 @@ void GameScene::resizeSprites(int delayForBackground)
     views().constFirst()->updateSceneRect(m_minSize);;
 
     //update pixmaps
-    emit resizeGraphics(m_SvgScaleFactor);
+    Q_EMIT resizeGraphics(m_SvgScaleFactor);
 
     //update overlay
     QRect viewRect = views().constFirst()->rect();
@@ -838,7 +827,7 @@ void GameScene::createBombItem(Bomb* bomb)
     bombItem->updateGraphics(m_SvgScaleFactor); //TODO: use a Renderer class and get the scale factor from a static function during initialization
 
     connect(this, &GameScene::resizeGraphics, bombItem, &BombItem::updateGraphics);
-    connect(bomb, SIGNAL(mortar(int,int,int,int)), bombItem, SLOT(updateMortar(int,int,int,int)));
+    connect(bomb, &Bomb::mortar, bombItem, &BombItem::updateMortar);
     connect(bomb, &Bomb::bombDetonated, this, &GameScene::bombDetonated);
     connect(bombItem, &BombItem::bombItemFinished, this, &GameScene::removeBombItem);
     connect(bombItem, &BombItem::animationFrameChanged, this, &GameScene::updateBombExplosionItemAnimation);
@@ -919,7 +908,7 @@ void GameScene::bombDetonated(Bomb* bomb)
     {
         bombElements = m_game->getArena()->getCell(nRow, nColumn).getElements(Granatier::Element::BOMB);
         int tempBombDetonationCountdown = nDetonationCountdown;
-        for(const auto& element: qAsConst(bombElements))
+        for(const auto& element: std::as_const(bombElements))
         {
             if(dynamic_cast <Bomb*> (element) != bomb && !(dynamic_cast <Bomb*> (element)->isDetonated()))
             {
@@ -931,7 +920,7 @@ void GameScene::bombDetonated(Bomb* bomb)
         blockElements = m_game->getArena()->getCell(nRow, nColumn).getElements(Granatier::Element::BLOCK);
         if(!blockElements.isEmpty())
         {
-            for(const auto& element: qAsConst(blockElements))
+            for(const auto& element: std::as_const(blockElements))
             {
                 dynamic_cast <Block*> (element)->startDestruction();
                 if (m_blockItems[nRow][nColumn] != nullptr)
@@ -986,7 +975,7 @@ void GameScene::bombDetonated(Bomb* bomb)
                 {
                     int tempBombDetonationCountdown = anDirectionDetonationCountdown[direction];
                     bool increaseDetonationTimeout = false;
-                    for(const auto& element: qAsConst(bombElements))
+                    for(const auto& element: std::as_const(bombElements))
                     {
                         if(dynamic_cast <Bomb*> (element) != bomb && !(dynamic_cast <Bomb*> (element)->isDetonated()))
                         {
@@ -1003,7 +992,7 @@ void GameScene::bombDetonated(Bomb* bomb)
                     if(!blockElements.isEmpty())
                     {
                         abDirectionsDone[direction] = true;
-                        for(const auto& element: qAsConst(blockElements))
+                        for(const auto& element: std::as_const(blockElements))
                         {
                             dynamic_cast <Block*> (element)->startDestruction();
                             if (m_blockItems[nRow][nColumn] != nullptr)
